<?php
// set application defaults
$defaults='INCLUDEFOLDER;IMAGEFOLDER;DATAFOLDER;IMPORTPROFILES;IMPORTDATA;TITLE;';

$inifile='autodirector.ini';
$ini=parse_ini_file($inifile);
foreach ($ini as $key=>$value) {
	define($key, $value);
	$defaults=str_replace($key.';', '', $defaults);
}
unset($ini);

// missing application defaults
if ($defaults!='') {
	print "The following parameters are missing from the $inifile file:\n $defaults";
	exit;
}
unset($defaults);

// ________________________________________________________
// MAIN APPLICATION

// PHP includes
require(INCLUDEFOLDER.'dbhandler.php');
require(INCLUDEFOLDER.'aduser.php');
require(INCLUDEFOLDER.'adsite.php');
require(INCLUDEFOLDER.'advehicle.php');
require(INCLUDEFOLDER.'adfunctions.php');
require(INCLUDEFOLDER.'adgraphicfunctions.php');

// set defaults
define('USERID', readCookie('aduserid'));
$setsite=getvar('siteid');
if ($setsite=='') define('SITEID', readCookie('adsiteid'));
else {
	// new site defined
	define ('SITEID', $setsite);
	writeCookie('adsiteid', SITEID);
}
define('SITEDATA',DATAFOLDER.SITEID.'/');
define('PICFOLDER',SITEDATA.'pics/');
define('THUMBFOLDER',SITEDATA.'thumbs/');
define('SITELOG',SITEDATA.'log.txt');
define('THISURL', $_SERVER['PHP_SELF']);
define('FULLURL', scriptPath());

// setup database object
$db=new dbObject;

// find out user information
$thisUser=new userObject;
$thisUser->selectDB($db);

// no user ID defined - return to login
if (USERID=='') {
	header('Location: '.FULLURL.'index.php');
	exit();
}
else {
	if (!$thisUser->fetchUser(USERID)) {
		print '<html><head><title>AutoDirector</title></head><body><p>The user account '.USERID.' is not defined, or a database communication error has occurred. Please <a href="index.php">log in again</a> or contact your administrator.</p></body></html>';
		exit();
	}
}

// find out site information
$thisSite=new siteObject;
$thisSite->selectDB($db);

if (!$thisSite->fetchSite(SITEID)) {
	print '<p>The site '.SITEID.' is not defined, or a database communication error has occurred. Processing cannot continue - please contact your administrator.</p>';
	exit();
}

// page header
$pagetitle=SITEID.' vehicle import wizard';
require(INCLUDEFOLDER.'adpagehead.php');

// JavaScript includes
print '<script type="text/javascript" src="'.INCLUDEFOLDER.'adscript.js"></script>';

// JavaScript setup
print "<script type=\"text/javascript\">\n";
print "run+=\"startup();\";\n";
print "function startup() { form=document.autodirector; }\n";
print "</script>\n";

// menu
showMenu('import');

// set page value
$page=postvar('page');

// get other values
$profile=postvar('profile');
$source=postvar('source');

// check if user authorised for this site
if ($thisUser->permissionLevel(SITEID)<3 && $thisSite->blockvehicleadmin) $page='nopermission';


// start form
print '<form name="autodirector" action="'.THISURL.'" method="post">';

// choose profile
showProfiles($page=='');

// choose source
showSources($page=='source');

// start import
startImport($page=='import');

// no permission page
showPermission($page=='nopermission');

// end form
print '</form>';

// disconnect from database
$db->dbDisconnect();
unset($db);

// unload variables
unset($thisSite);
unset($thisUser);

// page footer
require(INCLUDEFOLDER.'adpagefoot.php');


// ________________________________________________________
// list profiles
function showProfiles($show = false) {

	global $profile;

	if ($show) {

		print '<p><strong>STEP 1:</strong> The vehicle import wizard allows you to import vehicle data from various sources.</p>';

		$profilelist = fileList(IMPORTPROFILES, '/.*\.ini$/');
		$nprofs = count($profilelist);
		if ($nprofs == 0) {
			print '<p class="error">Profiles control how data is imported, but no profiles have been defined in '.IMPORTPROFILES.'. It is not possible to continue.</p>';
		}
		else {

			// show profiles
			print '<p><strong>Profiles</strong> control how data is imported. Please select a profile from the list:</p><div style="text-align:center"><select name="profile">';
			for ($p = 0; $p < $nprofs; $p++) {
				$ini=@parse_ini_file(IMPORTPROFILES.$profilelist[$p]);
				$type = $ini['PROFILENAME']." ($profilelist[$p] - ".$ini['DATAFORMAT'].' '.$ini['DATATYPE'].')';
				print "<option value=\"$profilelist[$p]\"";
				if ($profile == $profilelist[$p]) print ' selected="selected"';
				print ">$type</option>";
			}

			// next page
			doHidden('page', 'source');
			print '</select><br /><br /><input type="submit" value="next step &raquo;" /></div>';

		}

	}
	else {
		// not on this step
		doHidden('profile', $profile);
	}

}


// ________________________________________________________
// list sources
function showSources($show = false) {

	global $profile, $source;

	if ($show) {

		print '<p><strong>STEP 2:</strong> Please choose a data source.</p>';

		$ini = @parse_ini_file(IMPORTPROFILES.$profile);
		if ($ini!==false) {

			// get sources
			$importfrom = ($ini['IMPORTDATA'] ? $ini['IMPORTDATA'] : IMPORTDATA);

			$sourcelist = fileList($importfrom, $ini['DATAFILE']);
			$nsl = count($sourcelist);
			if ($nsl == 0) {
				print '<p class="error">No data sources could be found in '.FULLURL.$importfrom.' that match the filename '.$ini['DATAFILE'].'. It is not possible to continue.</p>';
			}
			else {

				// choose data
				doHidden('page', 'import');
				print '<table align="center" border="0" cellpadding="0" cellspacing="1">';

				print '<tr><td><strong>profile:</strong></td><td>'.$ini['PROFILENAME'].'</td></tr>';
				print '<tr><td><strong>data type:</strong></td><td>'.$ini['DATATYPE'].'</td></tr>';
				print '<tr><td><strong>format:</strong></td><td>'.$ini['DATAFORMAT'].'</td></tr>';

				print '<tr><td><strong>data source:</strong></td><td><select name="source">';
				for ($s = 0; $s < $nsl; $s++) print "<option value=\"$sourcelist[$s]\">$sourcelist[$s]</option>";
				print '</select></td></tr>';

				print '<tr><td><strong>first data row:</strong></td><td><input type="text" name="firstrow" value="'.$ini['FIRSTROW'].'" size="2" maxlength="4" style="text-align:right" /></td></tr>';
				print '<tr><td><strong>delete existing?</strong></td><td><input type="checkbox" name="deletefirst"'.($ini['DELETEFIRST'] ? ' checked="checked"' : '').' /></td></tr>';
				print '<tr><td colspan="2" style="text-align:center"><br /><input type="submit" value="import now &raquo;" /></td></tr>';
				print '</table><br clear="all" />';

			}

		}
		else {
			print '<p>The chosen profile, '.IMPORTPROFILES.$profile.', cannot be read. It may have been deleted.</p>';
		}

		// restart wizard
		print '<p align="right"><a href="importadmin.php"><img src="'.IMAGEFOLDER.'iconimport.gif" border="0" align="top" hspace="3">restart the vehicle import wizard</a></p>';

	}
	else {
		// not on this step
		doHidden('source', $source);
	}

}


// ________________________________________________________
// start import process
function startImport($show=false) {

	global $profile, $source;

	if ($show) {

		$error = false;

		// check profile and source
		$ini = @parse_ini_file(IMPORTPROFILES.$profile);
		if ($ini===false) {
			$error = true;
			print '<p class="error">The chosen profile, '.IMPORTPROFILES.$profile.', cannot be read. It may have been deleted.</p>';
		}
		else {
			$dataloc = ($ini['IMPORTDATA'] ? $ini['IMPORTDATA'] : IMPORTDATA);
			$data = $dataloc . $source;
			if (!file_exists($data)) {
				$error = true;
				print '<p class="error">The chosen data source, '.$data.', cannot be read. It may have been deleted.</p>';
			}
		}

		if (!$error) {

			// delete existing vehicles first?
			if (postvar('deletefirst') != '') print '<p>Deleting existing vehicles ... ' . deleteRecords() . '</p>';

			// find first row
			$firstrow=preg_replace('/\D/', '', postvar('firstrow'));
			if (is_numeric($firstrow)) $firstrow=intval($firstrow); else $firstrow=1;
			if ($firstrow < 1) $firstrow = 1;

			print "<p>Importing vehicle data from <strong>$data</strong>, starting at row <strong>$firstrow</strong> ... </p>";
			Import($ini, $dataloc, $data, $firstrow);
		}

		// restart wizard
		print '<p align="right"><a href="importadmin.php"><img src="'.IMAGEFOLDER.'iconimport.gif" border="0" align="top" hspace="3">restart the vehicle import wizard</a></p>';

	}

}


// ________________________________________________________
// import data using $ini parameters
function Import($ini, $dataloc, $data, $firstrow) {

	global $db, $thisSite, $thisUser;

	// fetch current rows
	if ($db->fetch('SELECT COUNT(*) FROM '.SITEID)) {
		$row = $db->row();
		$rc = $row[0];
	}
	else $rc = $thisSite->maxentries;

	$maxadd = max(0, $thisSite->maxentries - $rc);
	print "<p>Vehicles currently in <strong>".SITEID."</strong>: $rc";
	print '<br />Maximum vehicles permitted: ' . $thisSite->maxentries;
	if ($thisUser->supervisor) print '<br />You are logged in as a supervisor so all vehicles will be imported.';
	else print '<br />Maximum number of vehicles to import: ' . $maxadd;
	print '</p>';

	// get next record ID
	if ($db->fetch("SELECT MAX(id) FROM ".SITEID.";")) {
		$row=$db->row();
		$id=intval($row[0]);
	}
	else $id = 0;

	// open data file
	$fp = @fopen($data, 'r');
	if ($fp) {

		$end = ($maxadd < 1 ? true : false);
		$lnum = 0;
		$added = 0;
		$emsg = '';

		while (!$end && ($imp = fgetcsv($fp,99999,$ini['DATADELIMIT'])) !== false) {

			$nimp = count($imp);
			if ($nimp > 3) {

				$lnum++;

				// add record
				if ($lnum >= $firstrow) {

					$fail = false;
					array_unshift($imp, null);

					// initialise values
					$display = $ini['display'];
					$new = $ini['new'];
					$year = $ini['year'];
					$make = $ini['make'];
					$model = $ini['model'];
					$type = $ini['type'];
					$regnumber = $ini['regnumber'];
					$mileage = $ini['mileage'];
					$colour = $ini['colour'];
					$gearbox = $ini['gearbox'];
					$price = $ini['price'];
					$info = $ini['info'];
					$imagefile = $ini['imagefile'];

					// value substitution
					for ($i = 1; $i <= $nimp; $i++) {
						$imp[$i] = str_replace("'", "\'", trim($imp[$i]));
						$display = str_replace("[$i]", $imp[$i], $display);
						$new = str_replace("[$i]", $imp[$i], $new);
						$year = str_replace("[$i]", $imp[$i], $year);
						$make = str_replace("[$i]", $imp[$i], $make);
						$model = str_replace("[$i]", $imp[$i], $model);
						$type = str_replace("[$i]", $imp[$i], $type);
						$regnumber = str_replace("[$i]", $imp[$i], $regnumber);
						$mileage = str_replace("[$i]", $imp[$i], $mileage);
						$colour = str_replace("[$i]", $imp[$i], $colour);
						$gearbox = str_replace("[$i]", $imp[$i], $gearbox);
						$price = str_replace("[$i]", $imp[$i], $price);
						$info = str_replace("[$i]", $imp[$i], $info);
						$imagefile = str_replace("[$i]", $imp[$i], $imagefile);
					}

					// evaluate strings
					@eval('$display = '.$display.';');
					$display = !!($display);

					@eval('$new = '.$new.';');
					$new = !!($new);

					@eval('$year = '.$year.';');
					$year = intval($year);

					@eval('$make = '.$make.';');
					$make = htmlentities(html_entity_decode($make));

					@eval('$model = '.$model.';');
					$model = htmlentities(html_entity_decode($model));

					@eval('$type = '.$type.';');
					$type = htmlentities(html_entity_decode($type));

					@eval('$regnumber = '.$regnumber.';');
					$regnumber = htmlentities(html_entity_decode($regnumber));

					@eval('$mileage = '.$mileage.';');
					$mileage = intval($mileage);

					@eval('$colour = '.$colour.';');
					$colour = htmlentities(html_entity_decode($colour));

					@eval('$gearbox = '.$gearbox.';');
					if (strpos('[unknown][manual][automatic][tiptronic]', "[$gearbox]") === false) $gearbox = '';

					@eval('$price = '.$price.';');
					$price = intval($price);

					@eval('$info = '.$info.';');
					$info = str_replace('\n', "\n", htmlentities(html_entity_decode($info)));

					@eval('$imagefile = '.$imagefile.';');
					$imagefile = trim($imagefile);

					// echo "<p>display: $display, new: $new<br />$year $make $model $type<br />$colour; $regnumber; $mileage miles; $gearbox<br />price: $price<br />$info<br />image: $imagefile</p>";

					// find pictures
					$picturelist = ImportImages($dataloc, $imagefile);

					// update database
					$id++;
					$sql='INSERT INTO '.SITEID.' (id, display, new, year, make, model, type, regnumber, mileage, colour, gearbox, info, price, picturelist, userupdate, lastupdate) VALUES (';
					$sql.=SQLescape($id).', ';
					$sql.=SQLescape($display).', ';
					$sql.=SQLescape($new).', ';
					$sql.=SQLescape($year).', ';
					$sql.=SQLescape($make).', ';
					$sql.=SQLescape($model).', ';
					$sql.=SQLescape($type).', ';
					$sql.=SQLescape($regnumber).', ';
					$sql.=SQLescape($mileage).', ';
					$sql.=SQLescape($colour).', ';
					$sql.=SQLescape($gearbox).', ';
					$sql.=SQLescape($info).', ';
					$sql.=($price == '' ? 'null' : SQLescape($price)).', ';
					$sql.=SQLescape($picturelist).', ';
					$sql.=SQLescape($thisUser->email).', ';
					$sql.="'".gmdate('YmdHis')."');";
					$fail = (!$db->fetch($sql));
					if ($fail) $emsg .= "<br />The vehicle on line $lnum ($regnumber) could not be added.";

					if (!$fail) {
						// record added
						$added++;
						if (!$thisUser->supervisor && $added >= $maxadd) $end = true;
					}
				}

			}

		}

		// close data file
		fclose($fp);

		// errors
		if ($emsg != '') print "<p>The following errors were encountered:$emsg</p>";

		// updating files
		print '<p>Updating site files ... ';
		$gen = generateFiles($thisSite, FULLURL, DATAFOLDER);
		print ($gen == '' ? "completed" : $gen) . '</p>';

		// status
		print "<p>$added vehicle" . ($added == 1 ? '' : 's') . ' were imported - <a href="vehicleadmin.php?siteid='.SITEID.'">examine the vehicles</a> or <a href="listadmin.php?siteid='.SITEID.'">view integration options and example showrooms</a>.</p>';
	}
	else {
		print '<p class="error">Could not open the data file. Please contact your administrator.</p>';
	}

}

// ________________________________________________________
// import images
function ImportImages($dataloc, $filematch) {

	global $thisSite, $thisUser;

	$picturelist = '';
	$img = fileList($dataloc, $filematch);
	$added = 0;

	for ($i = 0; $i < count($img) && $added < $thisSite->maxpics; $i++) {

		$file = $dataloc.$img[$i];
		$error=false;
		$skipresize=false;

		// check file is a JPG
		$imginfo=@getimagesize($file);
		if ($imginfo[2]!=2) $error=true;

		// check that image is large enough
		if (!$error && $imginfo[0]<$thisSite->picdimension && $imginfo[1]<$thisSite->picdimension) {
			if ($thisSite->forcedimension) $error=true;
			else $skipresize=true;
		}

		// read image
		if (!$error) {
			$imgOrig=@imagecreatefromjpeg($file);
			if (!$imgOrig) $error=true;
		}

		// get image number
		if (!$error) {
			$imgNum=$thisSite->nextPic();
			if ($imgNum==0) $error=true;
		}

		// process image
		if (!$error) {

			if ($picturelist!='') $picturelist.=',';
			$picturelist.=$imgNum;

			// resize original (if necessary)
			if ($skipresize) {
				imagejpeg($imgOrig, PICFOLDER."$imgNum.jpg", 60);
			}
			else {
				$imgNew = sizeFix($imgOrig, $thisSite->picdimension);
				imagejpeg($imgNew, PICFOLDER."$imgNum.jpg", 60);
				imagedestroy($imgNew);
			}

			// create thumbnail
			$imgThumb = sizeExact($imgOrig, $thisSite->thumbdimx, $thisSite->thumbdimy);
			imagejpeg($imgThumb, THUMBFOLDER."$imgNum.jpg", 60);
			imagedestroy($imgThumb);

			imagedestroy($imgOrig);
			$added++;
		}

	}

	return $picturelist;

}


// ________________________________________________________
// show that user does not have the appropriate permissions
function showPermission($show=false) {
	if ($show) {
		print '<p class="error">You do not have permission to administer vehicles on this site. Please contact your administrator.</p>';
		print '<p>Site ID: '.SITEID.'<br />User ID: '.USERID.'</p>';
	}
}


// ________________________________________________________
// return array of of files in a folder (optional wildcard allowed)
function fileList($folder, $filematch = '//') {

	if ($filematch == '') $filematch = '//';
	$ret = array();
	if ($dir=opendir($folder)) {
		while (($file=readdir($dir)) !== false) {
			if ($file!="." && $file!=".." && !is_dir($folder.$file) && preg_match($filematch, $file)) $ret[] = $file;
		}
	}
	sort($ret);
	return $ret;
}
?>